@@ -226,6 +226,9 @@ bool ArgParser::parseArgs(int argc, char *argv[]) {
         javaOptions.push_back("-Dfile.encoding=UTF-8");
     }
 #endif
+    if (getenv("VERIFY_JRUBY") != NULL) {
+        noBootClassPath = true;
+    }
 
     addToArgList(args, argc, argv);
 
@@ -356,11 +359,7 @@ void ArgParser::prepareOptions() {
 #ifdef WIN32
     option += "cmd.exe";
 #else
-    const char* shell = getenv("SHELL");
-    if (shell == NULL) {
-        shell = "/bin/sh";
-    }
-    option += shell;
+    option += "/bin/sh";
 #endif
     javaOptions.push_back(option);
 
